==> atmc-http-0.0.2.0039-sources.jar: com/digiwin/athena/atmc/http/restful/ptm/controller/TestController.java <==
package com.digiwin.athena.atmc.http.restful.ptm.controller;

import com.digiwin.athena.appcore.auth.domain.AuthoredUser;
import com.digiwin.athena.atmc.http.constant.ErrorCodeEnum;
import com.digiwin.athena.atmc.http.constant.GlobalConstant;
import com.digiwin.athena.atmc.http.restful.HttpAssistantServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Marker;
import org.slf4j.MarkerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestAttribute;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.client.RestTemplate;

/**
 * @description:
 * @author: xusj
 * @date: 2023/6/27 13:42
 */
@Slf4j
@RestController
@RequestMapping(value = "/api/atmc/v1/test")
public class TestController {

    @Autowired
    private HttpAssistantServiceImpl httpAssistantService;

    @Autowired
    RestTemplate restTemplate;

    /**
     * 获取PTM-Data，专用于PTM的 submit-data Action
     * @return
     */
    @GetMapping("/errorCode")
    ResponseEntity<?> getPtmData(
            @RequestAttribute(value = GlobalConstant.AUTH_USER, required = false) AuthoredUser user){
         final Marker IMPORTANT_MARKER = MarkerFactory.getMarker("IMPORTANT");

//        String uri = "http://localhost:22100/api/ai/v1/bot/template/task/show/PWD_purchaseChangeOrder_userProject/ReplyPurchaseChangeDeliveryDate/321214502461568";
//        HttpHeaders headers = new HttpHeaders();
//        headers.setContentType(MediaType.APPLICATION_JSON);
//        Map<String, String> param = new HashMap<>();
//        param.put("taskId", "PWD_purchaseChangeOrder_userProject");
//        param.put("activityId", "ReplyPurchaseChangeDeliveryDate");
//        param.put("pageCode", "task-detail");
//        HttpEntity<?> httpEntity = new HttpEntity<>(headers);
//        ResponseEntity<BaseResultDTO<TmActivityResponseDTO>> responseEntity = null;
//
//        return responseEntity = restTemplate.exchange(uri, HttpMethod.GET, httpEntity,
//                new ParameterizedTypeReference<BaseResultDTO<TmActivityResponseDTO>>() {
//                }, param);
//        BusinessException be = ErrorCodeEnum.PTM_BACKLOG_IS_NULL.getBusinessException();
//        be.setErrorType(ErrorTypeEnum.BUSINESS.getValue());
//        log.error(IMPORTANT_MARKER,"evaluator");
        throw ErrorCodeEnum.PTM_BACKLOG_IS_NULL.getBusinessException();

    }

    // @SneakyThrows
    // @PostMapping("/change/lmc")
    // public String dto(@RequestBody JaPageReqDTO dto) {
    //     int pageNumber = dto.getPageNumber();
    //     return "ok";
    // }
}

==> atmc-http-0.0.2.0040-sources.jar: com/digiwin/athena/atmc/http/restful/ptm/controller/TestController.java <==
package com.digiwin.athena.atmc.http.restful.ptm.controller;

import com.digiwin.athena.appcore.auth.domain.AuthoredUser;
import com.digiwin.athena.atmc.http.constant.ErrorCodeEnum;
import com.digiwin.athena.atmc.http.constant.GlobalConstant;
import com.digiwin.athena.atmc.http.restful.HttpAssistantServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.slf4j.Marker;
import org.slf4j.MarkerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.*;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.client.RestTemplate;


/**
 * @description:
 * @author: xusj
 * @date: 2023/6/27 13:42
 */
@Slf4j
@RestController
@RequestMapping(value = "/api/atmc/v1/test")
public class TestController {

    @Autowired
    private HttpAssistantServiceImpl httpAssistantService;

    @Autowired
    RestTemplate restTemplate;

    /**
     * 获取PTM-Data，专用于PTM的 submit-data Action
     * @return
     */
    @GetMapping("/errorCode")
    ResponseEntity<?> getPtmData(
            @RequestAttribute(value = GlobalConstant.AUTH_USER, required = false) AuthoredUser user){
         final Marker IMPORTANT_MARKER = MarkerFactory.getMarker("IMPORTANT");

//        String uri = "http://localhost:22100/api/ai/v1/bot/template/task/show/PWD_purchaseChangeOrder_userProject/ReplyPurchaseChangeDeliveryDate/321214502461568";
//        HttpHeaders headers = new HttpHeaders();
//        headers.setContentType(MediaType.APPLICATION_JSON);
//        Map<String, String> param = new HashMap<>();
//        param.put("taskId", "PWD_purchaseChangeOrder_userProject");
//        param.put("activityId", "ReplyPurchaseChangeDeliveryDate");
//        param.put("pageCode", "task-detail");
//        HttpEntity<?> httpEntity = new HttpEntity<>(headers);
//        ResponseEntity<BaseResultDTO<TmActivityResponseDTO>> responseEntity = null;
//
//        return responseEntity = restTemplate.exchange(uri, HttpMethod.GET, httpEntity,
//                new ParameterizedTypeReference<BaseResultDTO<TmActivityResponseDTO>>() {
//                }, param);
//        BusinessException be = ErrorCodeEnum.PTM_BACKLOG_IS_NULL.getBusinessException();
//        be.setErrorType(ErrorTypeEnum.BUSINESS.getValue());
//        log.error(IMPORTANT_MARKER,"evaluator");
        throw ErrorCodeEnum.PTM_BACKLOG_IS_NULL.getBusinessException();

    }

//    @SneakyThrows
//    @PostMapping("/change/lmc")
//    public String dto(@RequestBody JaPageReqDTO dto) {
//        int pageNumber = dto.getPageNumber();
//        return "ok";
//    }
}
